@@ -32,7 +32,7 @@ gint  brl_ser_read_data      (gchar  *data_buff,
 			     gint    max_len);
 
 /* API */
-gint  brl_ser_open_port      (gint   port);
+gint  brl_ser_open_port      (gchar   *port);
 gint  handy_set_comm_param   ();            /* for HandyTech devices */
 gint  eco_set_comm_param     ();            /* for Eco devices */
 gint  brl_ser_set_comm_param (glong  baud_rate,
